
/**********************************************************************
  Author: Jason W. Bacon
  Created: Oct, 1999

  Description:
	Sets the foreground color on the current tty to the color
	specified on the command line.

	Note: Some terminfo patches are necessary for terminals
	that actually support color, but do not have color capabilities
	described in their terminfo entry. ( irix and xterm are common
	examples )

  Arguments:
	The color as a number from 0 to 7, or the word
	white, black, red, yellow, green, blue, magenta, or cyan

  Return values:
	See sysexits.h
 **********************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <sysexits.h>
#include <ctype.h>
#include <string.h>
#include <twintk.h>
#include <bacon.h>

int     main(int argc,char *argv[])

{
    term_t  *term;
    unsigned color_val;
    char    *term_type, *color, *end;
    
    switch(argc)
    {
	case    2:
	    color = argv[1];
	    if ( isdigit(*color) )
	    {
		color_val = strtoul(color,&end,10);
		if ( (color_val > 7) || (end == color) )
		{
		    fprintf(stderr,"%s: Invalid color: %s\n",argv[0],color);
		    return EX_DATAERR;
		}
	    }
	    else if ( strcasecmp(color,"black") == 0 )
		color_val = BLACK;
	    else if ( strcasecmp(color,"blue") == 0 )
		color_val = BLUE;
	    else if ( strcasecmp(color,"red") == 0 )
		color_val = RED;
	    else if ( strcasecmp(color,"yellow") == 0 )
		color_val = YELLOW;
	    else if ( strcasecmp(color,"green") == 0 )
		color_val = GREEN;
	    else if ( strcasecmp(color,"magenta") == 0 )
		color_val = MAGENTA;
	    else if ( strcasecmp(color,"white") == 0 )
		color_val = WHITE;
	    else if ( strcasecmp(color,"cyan") == 0 )
		color_val = CYAN;
	    else
	    {
		fprintf(stderr,"%s: Invalid color: %s\n",argv[0],color);
		return EX_DATAERR;
	    }
	    break;

	default:
	    fprintf(stderr,"Usage: %s <color>\n",argv[0]);
	    return EX_UNAVAILABLE;
    }
    
    term_type = getenv("TERM");
    if ( strcmp(term_type,"xterm") == 0 )
	term_type = "xterm-color";
    
    term = init_term(stdin,stdout,stderr,term_type,0);
    /*tprintf(term,"Terminal = %s  Colors = %d\n",term->term_type,
	    TMAX_COLORS(term));*/
    if ( term == NULL )
    {
	fputs("Cannot initialize terminal.\n",stderr);
	return EX_UNAVAILABLE;
    }
    if ( tset_foreground(term,color_val) == -1 )
    {
	fprintf(stderr,"Cannot set color on %s.\n",term_type);
	return EX_UNAVAILABLE;
    }
    /*tprintf(term,"Hello, world!\n");*/
    TFLUSH_OUT(term);
    return EX_OK;
}

